"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateBrokerClientUrl = void 0;
const logger_1 = require("../../../logs/logger");
const urlValidator_1 = require("../../../common/utils/urlValidator");
function validateBrokerClientUrl(checkOptions, config) {
    logger_1.log.debug({ checkId: checkOptions.id }, 'executing config check');
    const brokerClientUrl = config.BROKER_CLIENT_URL;
    try {
        if (brokerClientUrl && !isHttpUrl(brokerClientUrl)) {
            return {
                id: checkOptions.id,
                name: checkOptions.name,
                status: 'error',
                output: `Broker Client URL must use the HTTP or HTTPS protocols. Configured URL: ${brokerClientUrl}`,
            };
        }
        if (isHttpsWithoutCertificates(config)) {
            return {
                id: checkOptions.id,
                name: checkOptions.name,
                status: 'error',
                output: `Broker Client URL uses the HTTPS protocol: ${brokerClientUrl}, but HTTPS_CERT and HTTPS_KEY environment variables are missing.`,
            };
        }
        if (brokerClientUrl && isHostnameLocalhost(brokerClientUrl)) {
            return {
                id: checkOptions.id,
                name: checkOptions.name,
                status: 'warning',
                output: `Broker Client URL is configured for localhost: ${brokerClientUrl}. Webhooks might not work`,
            };
        }
        return {
            id: checkOptions.id,
            name: checkOptions.name,
            status: 'passing',
            output: 'config check: ok',
        };
    }
    catch (error) {
        const errorMessage = `Error executing check with checkId ${checkOptions.id}`;
        logger_1.log.debug({ error }, errorMessage);
        throw new Error(errorMessage);
    }
}
exports.validateBrokerClientUrl = validateBrokerClientUrl;
function isHttpUrl(brokerClientUrl) {
    logger_1.log.trace({ url: brokerClientUrl }, 'checking if URL is correctly configured');
    try {
        return ((0, urlValidator_1.urlContainsProtocol)(brokerClientUrl, 'http:') ||
            (0, urlValidator_1.urlContainsProtocol)(brokerClientUrl, 'https:'));
    }
    catch (error) {
        logger_1.log.error({ error }, 'Error checking URL HTTP protocol');
        return false;
    }
}
function isHttpsWithoutCertificates(config) {
    const brokerClientUrl = config.BROKER_CLIENT_URL;
    logger_1.log.trace({ url: brokerClientUrl }, 'checking if HTTPS is correctly configured');
    try {
        if (brokerClientUrl && (0, urlValidator_1.urlContainsProtocol)(brokerClientUrl, 'https:')) {
            const httpsCert = config.HTTPS_CERT || '';
            const httpsKey = config.HTTPS_KEY || '';
            logger_1.log.debug({ httpsCert: httpsCert, httpsKey: httpsKey }, 'configured HTTPS certificate and key');
            return httpsCert.length === 0 || httpsKey.length === 0;
        }
        return false;
    }
    catch (error) {
        logger_1.log.error({ error }, 'Error checking URL for HTTPS server');
        return false;
    }
}
function isHostnameLocalhost(brokerClientUrl) {
    logger_1.log.trace({ url: brokerClientUrl }, 'checking if localhost is used');
    try {
        const givenURL = new URL(brokerClientUrl);
        return givenURL.hostname === 'localhost';
    }
    catch (error) {
        logger_1.log.error({ error }, 'Error checking URL for using localhost');
        return false;
    }
}
//# sourceMappingURL=brokerClientUrlCheck.js.map